==> jc-1.4.0.tar.gz: ppg/util/AllowBreak.h <==
// class ppg.util.AllowBreak

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8a228f892f241e29 ppg_util_AllowBreak
// @dep_class 5146bf5a25ced51e ppg_util_Item

// header file dependencies
// @dep_header ppg_util_Item

#include "ppg/util/Item.h"

#ifndef _JC_ppg_util_AllowBreak_H_
#define _JC_ppg_util_AllowBreak_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_util_AllowBreak$sub_refs	_jc_ppg_util_AllowBreak$sub_refs;
typedef struct _jc_ppg_util_AllowBreak$sub_nonrefs	_jc_ppg_util_AllowBreak$sub_nonrefs;
typedef struct _jc_ppg_util_AllowBreak$refs	_jc_ppg_util_AllowBreak$refs;
typedef struct _jc_ppg_util_AllowBreak$nonrefs	_jc_ppg_util_AllowBreak$nonrefs;
typedef struct _jc_ppg_util_AllowBreak$object	_jc_ppg_util_AllowBreak$object;

typedef const struct _jc_ppg_util_AllowBreak$vmethods	_jc_ppg_util_AllowBreak$vmethods;
typedef const struct _jc_ppg_util_AllowBreak$vtable	_jc_ppg_util_AllowBreak$vtable;
typedef const struct _jc_ppg_util_AllowBreak$vtype	_jc_ppg_util_AllowBreak$vtype;

// Constructors
extern void _jc_ppg_util_AllowBreak$method$_init$206934d97c5ba451(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, jint, struct _jc_java_lang_String$object *);

// Virtual methods
extern jint _jc_ppg_util_AllowBreak$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean);
extern jint _jc_ppg_util_AllowBreak$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_ppg_util_AllowBreak$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_AllowBreak$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_ppg_util_AllowBreak$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean);
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint);
};

// Vtable
struct _jc_ppg_util_AllowBreak$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
	_jc_ppg_util_AllowBreak$vmethods	ppg_util_AllowBreak;
};

// Vtype
struct _jc_ppg_util_AllowBreak$vtype {
	_jc_type			type;
	_jc_ppg_util_AllowBreak$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_AllowBreak$sub_refs {
	struct _jc_java_lang_String$object	*alt;
};

// Reference instance fields (object)
struct _jc_ppg_util_AllowBreak$refs {
    _jc_ppg_util_AllowBreak$sub_refs	ppg_util_AllowBreak;
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_AllowBreak$sub_nonrefs {
	jint	indent;
	jboolean	broken;
};

// Non-reference instance fields (object)
struct _jc_ppg_util_AllowBreak$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
    _jc_ppg_util_AllowBreak$sub_nonrefs	ppg_util_AllowBreak;
};

// Object instance structure
struct _jc_ppg_util_AllowBreak$object {
	_jc_ppg_util_AllowBreak$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_AllowBreak$vtype	*vtype;
	_jc_ppg_util_AllowBreak$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_AllowBreak$vtype _jc_ppg_util_AllowBreak$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_AllowBreak, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_AllowBreak$class_object;

#endif	/* _JC_ppg_util_AllowBreak_H_ */

==> jc-1.4.6.tar.gz: ppg/util/AllowBreak.h <==
// class ppg.util.AllowBreak

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8a228f892f241e29 ppg_util_AllowBreak
// @dep_class 5146bf5a25ced51e ppg_util_Item

// header file dependencies
// @dep_header ppg_util_Item

#include "ppg/util/Item.h"

#ifndef _JC_ppg_util_AllowBreak_H_
#define _JC_ppg_util_AllowBreak_H_

// Forward structure declarations
struct _jc_java_io_Writer$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_util_AllowBreak$sub_refs	_jc_ppg_util_AllowBreak$sub_refs;
typedef struct _jc_ppg_util_AllowBreak$sub_nonrefs	_jc_ppg_util_AllowBreak$sub_nonrefs;
typedef struct _jc_ppg_util_AllowBreak$refs	_jc_ppg_util_AllowBreak$refs;
typedef struct _jc_ppg_util_AllowBreak$nonrefs	_jc_ppg_util_AllowBreak$nonrefs;
typedef struct _jc_ppg_util_AllowBreak$object	_jc_ppg_util_AllowBreak$object;

typedef const struct _jc_ppg_util_AllowBreak$vmethods	_jc_ppg_util_AllowBreak$vmethods;
typedef const struct _jc_ppg_util_AllowBreak$vtable	_jc_ppg_util_AllowBreak$vtable;
typedef const struct _jc_ppg_util_AllowBreak$vtype	_jc_ppg_util_AllowBreak$vtype;

// Constructors
extern void _jc_ppg_util_AllowBreak$method$_init$206934d97c5ba451(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, jint, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_ppg_util_AllowBreak$method$formatN$d2e3422217490f28(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
extern jint _jc_ppg_util_AllowBreak$method$sendOutput$7012ec94d3c70bcd(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_util_AllowBreak$method_info$formatN$d2e3422217490f28;
extern _jc_method _jc_ppg_util_AllowBreak$method_info$sendOutput$7012ec94d3c70bcd;

// Virtual methods structure
struct _jc_ppg_util_AllowBreak$vmethods {
	jint	(*formatN$d2e3422217490f28)(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, jint, jint, jint, jint, jboolean, jboolean) _JC_JCNI_ATTR;
	jint	(*sendOutput$7012ec94d3c70bcd)(_jc_env *, struct _jc_ppg_util_AllowBreak$object *, struct _jc_java_io_Writer$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_util_AllowBreak$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_util_Item$vmethods	ppg_util_Item;
	_jc_ppg_util_AllowBreak$vmethods	ppg_util_AllowBreak;
};

// Vtype
struct _jc_ppg_util_AllowBreak$vtype {
	_jc_type			type;
	_jc_ppg_util_AllowBreak$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_util_AllowBreak$sub_refs {
	struct _jc_java_lang_String$object	*alt;
};

// Reference instance fields (object)
struct _jc_ppg_util_AllowBreak$refs {
    _jc_ppg_util_AllowBreak$sub_refs	ppg_util_AllowBreak;
    _jc_ppg_util_Item$sub_refs	ppg_util_Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_util_AllowBreak$sub_nonrefs {
	jint	indent;
	jboolean	broken;
};

// Non-reference instance fields (object)
struct _jc_ppg_util_AllowBreak$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_util_Item$sub_nonrefs	ppg_util_Item;
    _jc_ppg_util_AllowBreak$sub_nonrefs	ppg_util_AllowBreak;
};

// Object instance structure
struct _jc_ppg_util_AllowBreak$object {
	_jc_ppg_util_AllowBreak$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_util_AllowBreak$vtype	*vtype;
	_jc_ppg_util_AllowBreak$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_util_AllowBreak$vtype _jc_ppg_util_AllowBreak$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_util_AllowBreak, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_util_AllowBreak$class_object;

#endif	/* _JC_ppg_util_AllowBreak_H_ */
